AdsVisibility class

Constructors

AdsVisibility({required bool banner, required bool interstitial, required bool native, required bool nativeBanner, required bool appOpen, required bool rewarded})
const
AdsVisibility.fromJson(Map<String, dynamic> json)
factory

Properties

appOpen bool
final
final
hashCode int
The hash code for this object.
no setterinherited
interstitial bool
final
native bool
final
nativeBanner bool
final
rewarded bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isVisible(AdType type) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultProduction → const AdsVisibility